@@ -116,9 +116,8 @@ class CornFlow(object):
         return response.json()
 
     @ask_token
-    def write_solution(self, execution_id, solution, log_text=None, log_json=None, state=1):
-        payload = dict(execution_results=solution, log_text=log_text, log_json=log_json, state=state)
-        response = self.put_api_for_id('dag/', id=execution_id, payload=payload)
+    def write_solution(self, execution_id, **kwargs):
+        response = self.put_api_for_id('dag/', id=execution_id, payload=kwargs)
         if response.status_code != 201:
             raise CornFlowApiError("Expected a code 201, got a {} error instead: {}".
                                    format(response.status_code, response.text))
